==> racer-0.1.1.tgz: package/lib/mixin.stm/AtomicModel.js <==
var AtomicModel, Serializer, proto, transaction;
Serializer = require('../Serializer');
transaction = require('../transaction');
proto = null;
AtomicModel = module.exports = function(id, parentModel) {
  var method, parentProto, _i, _len, _ref;
  AtomicModel = function(id, parentModel) {
    var adapter, self;
    self = this;
    self.id = id;
    self.parentModel = parentModel;
    adapter = self._adapter = parentModel._adapter;
    self.ver = adapter.version();
    self._specCache = {
      invalidate: function() {
        delete this.data;
        return delete this.lastTxnId;
      }
    };
    self._opCount = 0;
    self._txns = parentModel._txns;
    self._txnQueue = parentModel._txnQueue.slice(0);
    ['emit', 'on', 'once'].forEach(function(method) {
      return self[method] = function() {
        return parentModel[method].apply(parentModel, arguments);
      };
    });
  };
  AtomicModel.prototype = proto;
  parentProto = Object.getPrototypeOf(parentModel);
  _ref = ['_addOpAsTxn', '_queueTxn', '_specModel', '_applyMutation', '_dereference', 'set', 'setNull', 'del', 'incr', 'push', 'pop', 'unshift', 'shift', 'insertAfter', 'insertBefore', 'remove', 'splice', 'move'];
  for (_i = 0, _len = _ref.length; _i < _len; _i++) {
    method = _ref[_i];
    proto[method] = parentProto[method];
  }
  return new AtomicModel(id, parentModel);
};
proto = {
  isMyOp: function(id) {
    var extracted;
    extracted = id.substr(0, id.lastIndexOf('.'));
    return extracted === this.id;
  },
  oplog: function() {
    var id, modelId, txnQueue, txns, _i, _len, _results;
    modelId = this.id;
    txns = this._txns;
    txnQueue = this._txnQueue;
    _results = [];
    for (_i = 0, _len = txnQueue.length; _i < _len; _i++) {
      id = txnQueue[_i];
      if (this.isMyOp(id)) {
        _results.push(txns[id]);
      }
    }
    return _results;
  },
  _oplogAsTxn: function() {
    var ops, txn;
    ops = (function() {
      var _i, _len, _ref, _results;
      _ref = this.oplog();
      _results = [];
      for (_i = 0, _len = _ref.length; _i < _len; _i++) {
        txn = _ref[_i];
        _results.push(transaction.op.create({
          method: transaction.method(txn),
          args: transaction.args(txn),
          meta: transaction.meta(txn)
        }));
      }
      return _results;
    }).call(this);
    return transaction.create({
      base: this.ver,
      id: this.id,
      ops: ops
    });
  },
  _getVer: function() {
    return this.ver;
  },
  _commit: function() {},
  commit: function(callback) {
    var txn;
    txn = this._oplogAsTxn();
    this.parentModel._queueTxn(txn, callback);
    return this.parentModel._commit(txn);
  },
  get: function(path) {
    var val, ver, _ref;
    _ref = this._adapter.getWithVersion(path, this._specModel()), val = _ref[0], ver = _ref[1];
    if (ver <= this.ver) {
      this._addOpAsTxn('get', [path]);
    }
    return val;
  },
  _nextTxnId: function() {
    return this.id + '.' + ++this._opCount;
  },
  _conflictsWithMe: function(txn) {
    var id, modelId, myTxn, txnQueue, txns, _i, _len;
    modelId = this.id;
    txns = this._txns;
    txnQueue = this._txnQueue;
    for (_i = 0, _len = txnQueue.length; _i < _len; _i++) {
      id = txnQueue[_i];
      myTxn = txns[id];
      if (this.isMyOp(id && transaction.doesSharePath(txn, myTxn) && ver < transaction.base(txn))) {
        return true;
      }
    }
    return false;
  }
};

==> racer-0.1.3.tgz: package/lib/mixin.stm/AtomicModel.js <==
var AtomicModel, Serializer, proto, transaction;

Serializer = require('../Serializer');

transaction = require('../transaction');

proto = null;

AtomicModel = module.exports = function(id, parentModel) {
  var method, parentProto, _i, _len, _ref;
  AtomicModel = function(id, parentModel) {
    var adapter, self;
    self = this;
    self.id = id;
    self.parentModel = parentModel;
    adapter = self._adapter = parentModel._adapter;
    self.ver = adapter.version();
    self._specCache = {
      invalidate: function() {
        delete this.data;
        return delete this.lastTxnId;
      }
    };
    self._opCount = 0;
    self._txns = parentModel._txns;
    self._txnQueue = parentModel._txnQueue.slice(0);
    ['emit', 'on', 'once'].forEach(function(method) {
      return self[method] = function() {
        return parentModel[method].apply(parentModel, arguments);
      };
    });
  };
  AtomicModel.prototype = proto;
  parentProto = Object.getPrototypeOf(parentModel);
  _ref = ['_addOpAsTxn', '_queueTxn', '_specModel', '_applyMutation', '_dereference', 'set', 'setNull', 'del', 'incr', 'push', 'pop', 'unshift', 'shift', 'insertAfter', 'insertBefore', 'remove', 'splice', 'move'];
  for (_i = 0, _len = _ref.length; _i < _len; _i++) {
    method = _ref[_i];
    proto[method] = parentProto[method];
  }
  return new AtomicModel(id, parentModel);
};

proto = {
  isMyOp: function(id) {
    var extracted;
    extracted = id.substr(0, id.lastIndexOf('.'));
    return extracted === this.id;
  },
  oplog: function() {
    var id, modelId, txnQueue, txns;
    modelId = this.id;
    txns = this._txns;
    txnQueue = this._txnQueue;
    return (function() {
      var _i, _len, _results;
      _results = [];
      for (_i = 0, _len = txnQueue.length; _i < _len; _i++) {
        id = txnQueue[_i];
        if (this.isMyOp(id)) _results.push(txns[id]);
      }
      return _results;
    }).call(this);
  },
  _oplogAsTxn: function() {
    var ops, txn;
    ops = (function() {
      var _i, _len, _ref, _results;
      _ref = this.oplog();
      _results = [];
      for (_i = 0, _len = _ref.length; _i < _len; _i++) {
        txn = _ref[_i];
        _results.push(transaction.op.create({
          method: transaction.method(txn),
          args: transaction.args(txn),
          meta: transaction.meta(txn)
        }));
      }
      return _results;
    }).call(this);
    return transaction.create({
      base: this.ver,
      id: this.id,
      ops: ops
    });
  },
  _getVer: function() {
    return this.ver;
  },
  _commit: function() {},
  commit: function(callback) {
    var txn;
    txn = this._oplogAsTxn();
    this.parentModel._queueTxn(txn, callback);
    return this.parentModel._commit(txn);
  },
  get: function(path) {
    var val, ver, _ref;
    _ref = this._adapter.getWithVersion(path, this._specModel()), val = _ref[0], ver = _ref[1];
    if (ver <= this.ver) this._addOpAsTxn('get', [path]);
    return val;
  },
  _nextTxnId: function() {
    return this.id + '.' + ++this._opCount;
  },
  _conflictsWithMe: function(txn) {
    var id, modelId, myTxn, txnQueue, txns, _i, _len;
    modelId = this.id;
    txns = this._txns;
    txnQueue = this._txnQueue;
    for (_i = 0, _len = txnQueue.length; _i < _len; _i++) {
      id = txnQueue[_i];
      myTxn = txns[id];
      if (this.isMyOp(id && transaction.doesSharePath(txn, myTxn) && ver < transaction.base(txn))) {
        return true;
      }
    }
    return false;
  }
};
